api library

Classes

ApiClient
Boot
BootError
BootErrorTypeTransformer
Transformation class that can encode an instance of BootError to String, and decode dynamic data back to BootError.
Configuration
ConfigurationApi
ConfigurationConstraints
ConfigurationConstraintsConnections
ConfigurationConstraintsPorts
Connection
DeserializationMessage
Primarily intended for use in an isolate.
Error
Firewall
InfoApi
Ips
IpTableError
IpTableErrorTypeTransformer
Transformation class that can encode an instance of IpTableError to String, and decode dynamic data back to IpTableError.
LbFirewallStatus
Log
LogsApi
Mode
ModeTypeTransformer
Transformation class that can encode an instance of Mode to String, and decode dynamic data back to Mode.
Policy
PolicyTypeTransformer
Transformation class that can encode an instance of Policy to String, and decode dynamic data back to Policy.
ProtocolL4
ProtocolL4TypeTransformer
Transformation class that can encode an instance of ProtocolL4 to String, and decode dynamic data back to ProtocolL4.
ProtocolL7
ProtocolL7TypeTransformer
Transformation class that can encode an instance of ProtocolL7 to String, and decode dynamic data back to ProtocolL7.
Protocols
Service
ServiceApi
StatusFirewall
StatusIps
StatusRouter
Version

Properties

authenticator ↔ LogbotHttpBearerAuth
getter/setter pair
defaultApiClient ApiClient
getter/setter pair

Functions

cookiesToString(Map<String, String> cookies) String
Format a map of cookies to a header cookies String. LOGBOT: added this to support cookies
deserializeAsync(DeserializationMessage message) Future
Primarily intended for use in an isolate.
mapCastOfType<K, V>(dynamic map, String key) Map<K, V>?
Returns a valid Map<K, V> found at the specified Map key, null otherwise.
mapDateTime(dynamic map, String key, [String? pattern]) DateTime?
Returns a valid DateTime found at the specified Map key, null otherwise.
mapValueOfType<T>(dynamic map, String key) → T?
Returns a valid T value found at the specified Map key, null otherwise.
parameterToString(dynamic value) String
Format the given parameter object into a String.
serializeAsync(Object? value) Future<String>
Primarily intended for use in an isolate.