ConfigurationApi class

Constructors

ConfigurationApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

constraints({String? uuidToken}) Future<ConfigurationConstraints?>
Get configuration constraints
constraintsWithHttpInfo({String? uuidToken}) Future<Response>
Get configuration constraints
getConfig({String? uuidToken}) Future<Configuration?>
Get service configuration
getConfigWithHttpInfo({String? uuidToken}) Future<Response>
Get service configuration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConfig(Configuration configuration, {String? uuidToken}) Future<void>
Set a new configuration
setConfigWithHttpInfo(Configuration configuration, {String? uuidToken}) Future<Response>
Set a new configuration
toString() String
A string representation of this object.
inherited
validate(Configuration configuration, {String? uuidToken}) Future<void>
Validates a given configuration
validateWithHttpInfo(Configuration configuration, {String? uuidToken}) Future<Response>
Validates a given configuration

Operators

operator ==(Object other) bool
The equality operator.
inherited