ConfigurationConstraints class

Constructors

ConfigurationConstraints({required ConfigurationConstraintsPorts ports, List<String> versions = const [], List<Mode> modes = const [], required ConfigurationConstraintsConnections connections})
Returns a new ConfigurationConstraints instance.

Properties

connections ConfigurationConstraintsConnections
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
modes List<Mode>
getter/setter pair
ports ConfigurationConstraintsPorts
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versions List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ConfigurationConstraints?
Returns a new ConfigurationConstraints instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ConfigurationConstraints>?
mapFromJson(dynamic json) Map<String, ConfigurationConstraints>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ConfigurationConstraints>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.