Connection class

Constructors

Connection({required String name, required int localPort, required String remoteAddress, required int remotePort, required Protocols protocols, Firewall? firewall, Ips? ips, List<String> variables = const []})
Returns a new Connection instance.

Properties

firewall Firewall?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
ips Ips?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
localPort int
Minimum value: 0 Maximum value: 65535
getter/setter pair
name String
getter/setter pair
protocols Protocols
getter/setter pair
remoteAddress String
getter/setter pair
remotePort int
Minimum value: 0 Maximum value: 65535
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Connection?
Returns a new Connection instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Connection>?
mapFromJson(dynamic json) Map<String, Connection>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Connection>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.