Firewall class

Constructors

Firewall({List<String> whitelist = const [], List<String> blacklist = const [], required Policy defaultPolicy})
Returns a new Firewall instance.

Properties

blacklist List<String>
getter/setter pair
defaultPolicy Policy
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whitelist List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Firewall?
Returns a new Firewall instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Firewall>?
mapFromJson(dynamic json) Map<String, Firewall>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Firewall>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.