InfoApi class

Constructors

InfoApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

health({String? uuidToken}) Future<void>
Check Logbot Firewall status
healthWithHttpInfo({String? uuidToken}) Future<Response>
Check Logbot Firewall status
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
version({String? uuidToken}) Future<Version?>
Get Logbot Firewall version
versionWithHttpInfo({String? uuidToken}) Future<Response>
Get Logbot Firewall version

Operators

operator ==(Object other) bool
The equality operator.
inherited