LbFirewallStatus class

Constructors

LbFirewallStatus({DateTime? timestamp, required bool running, required Mode mode, required Boot boot, StatusRouter? router, StatusFirewall? firewall, StatusIps? ips})
Returns a new LbFirewallStatus instance.

Properties

boot Boot
getter/setter pair
firewall StatusFirewall?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
ips StatusIps?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
mode Mode
getter/setter pair
router StatusRouter?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
running bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) LbFirewallStatus?
Returns a new LbFirewallStatus instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<LbFirewallStatus>?
mapFromJson(dynamic json) Map<String, LbFirewallStatus>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<LbFirewallStatus>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.