LogsApi class

Constructors

LogsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIpsLogs({String? uuidToken, DateTime? from, DateTime? to, String? srcIp, int? srcPort, String? dstIp, int? dstPort, List<ProtocolL4>? protocolLv4, ProtocolL7? protocolLv7}) Future<List<Log>?>
Retrive IPS logs
getIpsLogsWithHttpInfo({String? uuidToken, DateTime? from, DateTime? to, String? srcIp, int? srcPort, String? dstIp, int? dstPort, List<ProtocolL4>? protocolLv4, ProtocolL7? protocolLv7}) Future<Response>
Retrive IPS logs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited