ProtocolL4 class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) ProtocolL4?
listFromJson(dynamic json, {bool growable = false}) List<ProtocolL4>?

Constants

tcp → const ProtocolL4
udp → const ProtocolL4
values → const List<ProtocolL4>
List of all possible values in this ProtocolL4.