ProtocolL7 class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) ProtocolL7?
listFromJson(dynamic json, {bool growable = false}) List<ProtocolL7>?

Constants

any → const ProtocolL7
enip → const ProtocolL7
http → const ProtocolL7
modbus → const ProtocolL7
none → const ProtocolL7
opcua → const ProtocolL7
s7comm → const ProtocolL7
s7commplus → const ProtocolL7
values → const List<ProtocolL7>
List of all possible values in this ProtocolL7.