ServiceApi class

Constructors

ServiceApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable({String? uuidToken}) Future<void>
Disables firewall
disableWithHttpInfo({String? uuidToken}) Future<Response>
Disables firewall
enable({String? uuidToken}) Future<void>
Enables firewall
enableWithHttpInfo({String? uuidToken}) Future<Response>
Enables firewall
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restart({String? uuidToken}) Future<void>
Restarts firewall
restartWithHttpInfo({String? uuidToken}) Future<Response>
Restarts firewall
status({String? uuidToken}) Future<LbFirewallStatus?>
Get service status
statusWithHttpInfo({String? uuidToken}) Future<Response>
Get service status
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited