StatusRouter class

Constructors

StatusRouter({required bool running, List<IpTableError> errors = const []})
Returns a new StatusRouter instance.

Properties

errors List<IpTableError>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
running bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StatusRouter?
Returns a new StatusRouter instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StatusRouter>?
mapFromJson(dynamic json) Map<String, StatusRouter>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StatusRouter>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.