Configuration class
Constructors
-
Configuration({required String version, int? release, DateTime? createdAt, required Service service, Firewall? firewall, List<
Connection> connections = const []}) - Returns a new Configuration instance.
Properties
-
connections
↔ List<
Connection> -
getter/setter pair
- createdAt ↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- firewall ↔ Firewall?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- release ↔ int?
-
Minimum value: 0
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service ↔ Service
-
getter/setter pair
- version ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Configuration? -
Returns a new Configuration instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< Configuration> ? -
mapFromJson(
dynamic json) → Map< String, Configuration> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< Configuration> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.