Log class
Constructors
- Log({required DateTime timestamp, required int flowId, required String srcIp, required int srcPort, required String dstIp, required int dstPort, required ProtocolL4 protoLv4, required ProtocolL7 protoLv7, required String action, required String signature, required String category, required Object payload})
- Returns a new Log instance.
Properties
- action ↔ String
-
getter/setter pair
- category ↔ String
-
getter/setter pair
- dstIp ↔ String
-
getter/setter pair
- dstPort ↔ int
-
getter/setter pair
- flowId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- payload ↔ Object
-
getter/setter pair
- protoLv4 ↔ ProtocolL4
-
getter/setter pair
- protoLv7 ↔ ProtocolL7
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature ↔ String
-
getter/setter pair
- srcIp ↔ String
-
getter/setter pair
- srcPort ↔ int
-
getter/setter pair
- timestamp ↔ DateTime
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Log? -
Returns a new Log instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< Log> ? -
mapFromJson(
dynamic json) → Map< String, Log> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< Log> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.